package com.ruoyi.web.controller.base;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.base.domain.DialogueLog;
import com.ruoyi.base.service.IDialogueLogService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 对话日志Controller
 *
 * @author ruoyi
 * @date 2026-05-19
 */
@RestController
@RequestMapping("/base/dialogueLog")
public class DialogueLogController extends BaseController
{
    @Autowired
    private IDialogueLogService dialogueLogService;

    /**
     * 查询对话日志列表
     */
    @PreAuthorize("@ss.hasPermi('base:dialogueLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(DialogueLog dialogueLog)
    {
        startPage();
        List<DialogueLog> list = dialogueLogService.selectDialogueLogList(dialogueLog);
        return getDataTable(list);
    }

    /**
     * 导出对话日志列表
     */
    @PreAuthorize("@ss.hasPermi('base:dialogueLog:export')")
    @Log(title = "对话日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DialogueLog dialogueLog)
    {
        List<DialogueLog> list = dialogueLogService.selectDialogueLogList(dialogueLog);
        ExcelUtil<DialogueLog> util = new ExcelUtil<DialogueLog>(DialogueLog.class);
        util.exportExcel(response, list, "对话日志数据");
    }

    /**
     * 获取对话日志详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:dialogueLog:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(dialogueLogService.selectDialogueLogById(id));
    }

    /**
     * 新增对话日志
     */
    @PreAuthorize("@ss.hasPermi('base:dialogueLog:add')")
    @Log(title = "对话日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DialogueLog dialogueLog)
    {
        return toAjax(dialogueLogService.insertDialogueLog(dialogueLog));
    }

    /**
     * 修改对话日志
     */
    @PreAuthorize("@ss.hasPermi('base:dialogueLog:edit')")
    @Log(title = "对话日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DialogueLog dialogueLog)
    {
        return toAjax(dialogueLogService.updateDialogueLog(dialogueLog));
    }

    /**
     * 删除对话日志
     */
    @PreAuthorize("@ss.hasPermi('base:dialogueLog:remove')")
    @Log(title = "对话日志", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(dialogueLogService.deleteDialogueLogByIds(ids));
    }
}
